==> ikapi-1.5.0.tgz: package/index.js <==
// Set options as a parameter, environment variable, or rc file.
// eslint-disable-next-line no-global-assign
require = require("esm")(module/* , options */);
//Set defaults
global.Promise = require("bluebird");
//
module.exports = {
  //Main components
  IKTransaction: require("./src/IKTransaction.js").default,
  IKRouter: require("./src/IKRouter.js").default,
  IKEventProcessor: require('./src/IKEventProcessor.js').default,
  IKDynamoStream: require('./src/IKDynamoStream.js').default,
  IKProcess: require("./src/IKProcess.js").default,
  //Helpers
  Utils: require("./src/API/IKUtils.js").default,
  //Answers
  IKResponse: require("./src/API/IKResponse.js").default,
  IKBadRequestResponse: require("./src/API/IKResponse.js").IKBadRequestResponse,
  IKUnauthorizedResponse: require("./src/API/IKResponse.js").IKUnauthorizedResponse,
  IKMissingParamResponse: require("./src/API/IKResponse.js").IKMissingParamResponse,
  IKSuccessResponse: require("./src/API/IKResponse.js").IKSuccessResponse,
  IKSuccessStreamResponse: require("./src/API/IKResponse.js").IKSuccessStreamResponse,
  IKSuccessNoContentResponse: require("./src/API/IKResponse.js").IKSuccessNoContentResponse,
  //Database queries
  IKDBQueryScan: require("./src/Database/IKDBQueryScan.js").default,
  IKDBQueryGet: require("./src/Database/IKDBQueryGet.js").default,
  IKDBQueryPut: require("./src/Database/IKDBQueryPut.js").default,
  IKDBQueryUpdate: require("./src/Database/IKDBQueryUpdate.js").default,
  IKDBQueryDelete: require("./src/Database/IKDBQueryDelete.js").default,
  IKDBQueryBatchWrite: require("./src/Database/IKDBQueryBatchWrite.js").default,
  IKDBQueryTransactionalWrite: require("./src/Database/IKDBQueryTransactionalWrite.js").default,
  IKDBExpressionOperator: require("./src/Database/IKDBBaseExpression.js").IKDBExpressionOperator,
  //Mailer
  IKMailer: require('./src/Mailer/IKMailer.js').default
};

==> ikapi-1.5.2.tgz: package/index.js <==
// Set options as a parameter, environment variable, or rc file.
// eslint-disable-next-line no-global-assign
require = require("esm")(module/* , options */);
//Set defaults
global.Promise = require("bluebird");
//
module.exports = {
  //Main components
  IKTransaction: require("./src/BaseEvent/IKTransaction.js").default,
  IKRouter: require("./src/IKRouter.js").default,
  IKEventProcessor: require('./src/IKEventProcessor.js').default,
  IKDynamoStream: require('./src/IKDynamoStream.js').default,
  IKProcess: require("./src/IKProcess.js").default,
  //Helpers
  Utils: require("./src/API/IKUtils.js").default,
  //Answers
  IKResponse: require("./src/API/IKResponse.js").default,
  IKBadRequestResponse: require("./src/API/IKResponse.js").IKBadRequestResponse,
  IKUnauthorizedResponse: require("./src/API/IKResponse.js").IKUnauthorizedResponse,
  IKMissingParamResponse: require("./src/API/IKResponse.js").IKMissingParamResponse,
  IKSuccessResponse: require("./src/API/IKResponse.js").IKSuccessResponse,
  IKSuccessStreamResponse: require("./src/API/IKResponse.js").IKSuccessStreamResponse,
  IKSuccessNoContentResponse: require("./src/API/IKResponse.js").IKSuccessNoContentResponse,
  //Database queries
  IKDBQueryScan: require("./src/Database/IKDBQueryScan.js").default,
  IKDBQueryGet: require("./src/Database/IKDBQueryGet.js").default,
  IKDBQueryPut: require("./src/Database/IKDBQueryPut.js").default,
  IKDBQueryUpdate: require("./src/Database/IKDBQueryUpdate.js").default,
  IKDBQueryDelete: require("./src/Database/IKDBQueryDelete.js").default,
  IKDBQueryBatchWrite: require("./src/Database/IKDBQueryBatchWrite.js").default,
  IKDBQueryTransactionalWrite: require("./src/Database/IKDBQueryTransactionalWrite.js").default,
  IKDBExpressionOperator: require("./src/Database/IKDBBaseExpression.js").IKDBExpressionOperator,
  //Mailer
  IKMailer: require('./src/Mailer/IKMailer.js').default
};
